package main

import (
	"context"
	"fmt"
	"log"
	"os"

	"gocloud.dev/docstore"
	_ "gocloud.dev/docstore/gcpfirestore"
)

func main() {
	err := run()
	if err != nil {
		log.Print(err)
		os.Exit(1)
	}
}

func run() error {
	ctx := context.Background()

	project := os.Getenv("GCP_PROJECT_NAME")
	if project == "" {
		return fmt.Errorf("GCP_PROJECT_NAME environment variable not specified")
	}

	url := fmt.Sprintf(
		"firestore://projects/%s/databases/(default)/documents/collection?name_field=ID",
		project)

	coll, err := docstore.OpenCollection(ctx, url)
	if err != nil {
		return fmt.Errorf("could not open collection: %w", err)

	}
	defer coll.Close()

	err = coll.Put(ctx, &Entry{ID: "foo"})
	if err != nil {
		return fmt.Errorf("could not save foo: %w", err)
	}
	return nil
}

type Entry struct {
	ID string
}
